#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""This script searches for items matching the search.xml file in the
folder /usr/local/cpaa."""

import sys
import requests
import xml.etree.ElementTree as ET
import urllib
import ConfigParser
import os


"""first read the config files and get some settings."""
vs_config = ConfigParser.ConfigParser()
vs_config.read('/etc/cantemo/portal/portal.conf')
# get the Vidispine user name.
VS_name = vs_config.get('vidispine', 'VIDISPINE_USERNAME', 0)
# get the Vidispine password.
VS_password = vs_config.get('vidispine', 'VIDISPINE_PASSWORD', 0)


"""Search for media which have been created x days before now"""

# prepare Vidispine search
headers = {'Content-Type': 'application/xml', 'Accept': 'application/xml'}


# check if we find our search.xml file and read its content
search_xml_file = os.path.join("/", "usr", "local", "cpaa", "search.xml")
try:
    with open(search_xml_file, "r") as f:
        xml = f.read()
except IOError as err:
    print("File /usr/local/cpaa/search.xml doesn't exist. Quitting.")
    sys.exit(1)

# remove line breaks and tabs within the above xml and uri encode it
xml = urllib.quote(xml.replace("\n", "").replace("	", ""))

archive_candidates = []

vidispine_xml_name_space = "{http://xml.vidispine.com/schema/vidispine}"

def get_matching_items(first):
    my_response = requests.get(
        "http://localhost:8080/API/item;first=%s;number=1000?q=%s" % (
        first, xml), auth=(VS_name, VS_password), headers=headers)
    my_response = ET.fromstring(my_response.content)
    results = 0
    for field in my_response.findall(
                    "./%(ns)sitem" % {"ns": vidispine_xml_name_space}):
        item_id = field.attrib["id"]
        results += 1
        archive_candidates.append(item_id)
    if results == 1000:
        first += 1000
        get_matching_items(first)

get_matching_items(1)

if archive_candidates == []:
    print("No matching items found")
else:
    print("These items match your search:")
    counter = 0
    for i in archive_candidates:
        counter += 1
        if counter < len(archive_candidates):
            print("%s, " % i),
        else:
            print(i)
    print("%s matching items found." % len(archive_candidates))
